# Cluster

::: geneva.cluster.mgr.GenevaCluster

::: geneva.cluster.builder.KubeRayClusterBuilder

::: geneva.cluster.builder.LocalRayClusterBuilder

::: geneva.cluster.builder.ExternalRayClusterBuilder

::: geneva.cluster.builder.CpuWorkerBuilder
    options:
        inherited_members: true

::: geneva.cluster.builder.GpuWorkerBuilder
    options:
        inherited_members: true

::: geneva.cluster.mgr.HeadGroupConfig

::: geneva.cluster.mgr.WorkerGroupConfig

::: geneva.cluster.mgr.KubeRayConfig

::: geneva.cluster.mgr.ClusterConfigManager

::: geneva.cluster.GenevaClusterType

::: geneva.cluster.K8sConfigMethod
